@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backend.py 10376 2017-10-17 03:32:51Z David $
+# $Id: Backend.py 10398 2017-10-24 07:23:41Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-17 11:32:51 +0800 (Tue, 17 Oct 2017) $
-# $Revision: 10376 $
+# $Date: 2017-10-24 15:23:41 +0800 (Tue, 24 Oct 2017) $
+# $Revision: 10398 $
 
 from urllib import urlopen, urlencode, quote
 from django.core.mail.backends.base import BaseEmailBackend
+from django.conf import settings
 
 from Iuppiter.Encoding import utf8, _unicode
 from Iuppiter.Json import serializer
@@ -31,7 +32,6 @@ class EmailBackend(BaseEmailBackend):
         super(EmailBackend, self).__init__(fail_silently=fail_silently)
 
         if not username:
-            from django.conf import settings
             username = settings.EMAIL_HOST_USER 
             password = settings.EMAIL_HOST_PASSWORD
             host = settings.EMAIL_HOST
@@ -128,11 +128,24 @@ class EmailBackend(BaseEmailBackend):
                 fromMail = self.from_email
             else:
                 fromMail = email.from_email
+
+            if hasattr(email, 'alternatives'):
+                # if email is multipart/alternative email
+                # [(u'\n<p xmlns="http:/...eam</p>\n', 'text/html')]
+                # see https://docs.djangoproject.com/en/1.11/topics/
+                #     email/#send-mail
+                if email.alternatives:
+                    emailText = email.alternatives[0][0]
+                else:
+                    emailText = '<pre>%s</pre>' % (email.body, )
+            else:
+                emailText = '<pre>%s</pre>' % (email.body, )
+
             data = {
                 'token': token,
                 'title': title,
                 'emails': ','.join(email.to),
-                'text': utf8(email.body),
+                'text': utf8(emailText),
                 'sender': fromMail,
             }
 
