@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: views.py 10403 2017-10-24 08:52:47Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,10 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
+# $Author: David $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 9579 $
-
+# $Revision: 10403 $
+from django.shortcuts import render_to_response, get_object_or_404
+from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.csrf import csrf_exempt
 from django.template.loader import render_to_string
 from django.core.urlresolvers import reverse
@@ -22,9 +23,12 @@ from django.shortcuts import redirect
 from django.conf import settings
 from django.contrib.admin.views.decorators import staff_member_required
 
+from Iuppiter.dispatch import ThreadPool
 from Iuppiter.extension.views import jsonpCallback
 
-from Theophrastus.models import Newsletter
+from Theophrastus.models import MailingList, Newsletter, 
+                                ContactMailingStatus, Contact
+from Theophrastus.cloud.Mailer import CloudMailer
 from Theophrastus.newsletter_extension.models import Header, Footer
 
 @staff_member_required
